"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wizardSubmit = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const web3_js_1 = require("@solana/web3.js");
const chat_1 = require("@strata-foundation/chat");
const spl_token_bonding_1 = require("@strata-foundation/spl-token-bonding");
const spl_utils_1 = require("@strata-foundation/spl-utils");
const defaultBondingOpts = {
    baseMint: spl_token_1.NATIVE_MINT,
    buyBaseRoyaltyPercentage: 0,
    buyTargetRoyaltyPercentage: 5,
    sellBaseRoyaltyPercentage: 0,
    sellTargetRoyaltyPercentage: 0,
    targetMintDecimals: 9,
};
const getCurveConfig = (startingPrice) => {
    const k = 1;
    const c = startingPrice * (k + 1);
    return new spl_token_bonding_1.TimeCurveConfig()
        .addCurve(0, new spl_token_bonding_1.TimeDecayExponentialCurveConfig({
        c,
        k0: 0,
        k1: 0,
        d: 1,
        interval: 0,
    }))
        .addCurve(30 * 60, // 30 minutes
    new spl_token_bonding_1.TimeDecayExponentialCurveConfig({
        c,
        k0: 0,
        k1: k,
        d: 0.5,
        interval: 1.5 * 60 * 60, // 1.5 hours
    }));
};
const getPermissionType = (typeString) => {
    if (!typeString)
        return undefined;
    return {
        native: chat_1.PermissionType.Native,
        token: chat_1.PermissionType.Token,
        nft: chat_1.PermissionType.NFT,
    }[typeString];
};
const getMetadataOpts = ({ identifier, uri, }) => new mpl_token_metadata_1.DataV2({
    name: identifier.substring(0, 32),
    symbol: identifier.substring(0, 10),
    uri,
    sellerFeeBasisPoints: 0,
    creators: null,
    collection: null,
    uses: null,
});
const getJsonFile = (arg0) => new File([new Blob([JSON.stringify(arg0)], { type: "application/json" })], "file.json");
const wizardSubmit = ({ sdks, data: { wizardData }, delegateWallet, setState, }) => __awaiter(void 0, void 0, void 0, function* () {
    const { chatSdk, tokenBondingSdk } = sdks;
    let innerError = null;
    const { name, identifier, imageUrl } = wizardData;
    const { readForm, postForm, postIsSameAsRead } = wizardData;
    if (chatSdk && tokenBondingSdk) {
        setState({ status: "submitting", error: undefined });
        let readPermissionType, readPermissionAmount, readPermissionKey;
        let postPermissionType, postPermissionAmount, postPermissionKey;
        let readPermissionInstructions = [], readPermissionSigners = [], postPermissionInstructions = [], postPermissionSigners = [];
        readPermissionType = getPermissionType(readForm.type);
        readPermissionAmount = readForm.amount;
        readPermissionKey =
            readForm.type === "native" || readForm.type === "token"
                ? readForm.mint
                    ? new web3_js_1.PublicKey(readForm.mint)
                    : undefined
                : readForm.type === "nft"
                    ? new web3_js_1.PublicKey(readForm.collectionKey)
                    : undefined;
        postPermissionType = getPermissionType(postForm.type);
        postPermissionAmount = postForm.amount;
        postPermissionKey =
            postForm.type === "native" || postForm.type === "token"
                ? postForm.mint
                    ? new web3_js_1.PublicKey(postForm.mint)
                    : undefined
                : postForm.type === "nft"
                    ? new web3_js_1.PublicKey(postForm.collectionKey)
                    : undefined;
        if (!readPermissionKey || !postPermissionKey) {
            if (!readPermissionKey) {
                readPermissionAmount = (0, spl_utils_1.toBN)(readForm.amount, defaultBondingOpts.targetMintDecimals);
                const targetMintKeypair = web3_js_1.Keypair.generate();
                const file = getJsonFile({
                    name,
                    symbol: identifier,
                    description: postIsSameAsRead
                        ? `Permission token for ${identifier} chat`
                        : `Read permission token for ${identifier} chat`,
                    image: imageUrl,
                    mint: targetMintKeypair.publicKey,
                });
                (0, chat_1.randomizeFileName)(file);
                try {
                    setState({
                        subStatus: "Uploading read token metadata to SHDW drive...",
                    });
                    const uri = yield (0, chat_1.uploadFiles)(chatSdk.provider, [file], delegateWallet);
                    if (!uri || !uri.length)
                        throw new Error("Failed to upload token metadata");
                    const metadata = getMetadataOpts({
                        identifier: `${postIsSameAsRead ? "" : "READ"}${identifier}`,
                        uri: uri[0],
                    });
                    const curveOut = yield tokenBondingSdk.initializeCurveInstructions({
                        config: getCurveConfig(readForm.startingPrice),
                    });
                    const bondingOpts = Object.assign(Object.assign({}, defaultBondingOpts), { targetMint: targetMintKeypair.publicKey, curve: curveOut.output.curve });
                    const metaOut = yield chatSdk.createMetadataForBondingInstructions({
                        targetMintKeypair,
                        metadataUpdateAuthority: chatSdk.wallet.publicKey,
                        metadata,
                        decimals: bondingOpts.targetMintDecimals,
                    });
                    const bondingOut = yield tokenBondingSdk.createTokenBondingInstructions(bondingOpts);
                    readPermissionKey = bondingOut.output.targetMint;
                    readPermissionInstructions.push([...curveOut.instructions, ...metaOut.instructions], bondingOut.instructions);
                    readPermissionSigners.push([...curveOut.signers, ...metaOut.signers], bondingOut.signers);
                    readPermissionKey = targetMintKeypair.publicKey;
                }
                catch (e) {
                    innerError = e;
                    setState({
                        error: e,
                    });
                }
            }
            if (!postPermissionKey && !innerError) {
                if (postIsSameAsRead) {
                    postPermissionKey = readPermissionKey;
                    postPermissionAmount = readPermissionAmount;
                    postPermissionType = readPermissionType;
                }
                else {
                    postPermissionAmount = (0, spl_utils_1.toBN)(readForm.amount, defaultBondingOpts.targetMintDecimals);
                    const targetMintKeypair = web3_js_1.Keypair.generate();
                    const file = getJsonFile({
                        name,
                        symbol: identifier,
                        description: `Post permission token for ${identifier} chat`,
                        image: imageUrl,
                        mint: targetMintKeypair.publicKey,
                    });
                    (0, chat_1.randomizeFileName)(file);
                    try {
                        setState({
                            subStatus: "Uploading post token metadata to SHDW drive...",
                        });
                        const uri = yield (0, chat_1.uploadFiles)(chatSdk.provider, [file], delegateWallet);
                        if (!uri || !uri.length)
                            throw new Error("Failed to upload token metadata");
                        const metadata = getMetadataOpts({
                            identifier: `POST${identifier}`,
                            uri: uri[0],
                        });
                        const curveOut = yield tokenBondingSdk.initializeCurveInstructions({
                            config: getCurveConfig(readForm.startingPrice),
                        });
                        const bondingOpts = Object.assign(Object.assign({}, defaultBondingOpts), { targetMint: targetMintKeypair.publicKey, curve: curveOut.output.curve });
                        const metaOut = yield chatSdk.createMetadataForBondingInstructions({
                            targetMintKeypair,
                            metadataUpdateAuthority: chatSdk.wallet.publicKey,
                            metadata,
                            decimals: bondingOpts.targetMintDecimals,
                        });
                        const bondingOut = yield tokenBondingSdk.createTokenBondingInstructions(bondingOpts);
                        postPermissionKey = bondingOut.output.targetMint;
                        postPermissionInstructions.push([...curveOut.instructions, ...metaOut.instructions], bondingOut.instructions);
                        postPermissionSigners.push([...curveOut.signers, ...metaOut.signers], bondingOut.signers);
                        postPermissionKey = targetMintKeypair.publicKey;
                    }
                    catch (e) {
                        innerError = e;
                        setState({
                            error: e,
                        });
                    }
                }
            }
        }
        if (!innerError) {
            const chatOut = yield chatSdk.initializeChatInstructions({
                name,
                identifier,
                imageUrl,
                permissions: {
                    readPermissionKey: readPermissionKey,
                    defaultReadPermissionAmount: readPermissionAmount,
                    readPermissionType,
                    postPermissionKey: postPermissionKey,
                    postPermissionAmount,
                    postPermissionType,
                },
            });
            setState({
                subStatus: `Creating ${identifier} chat...`,
            });
            try {
                yield (0, spl_utils_1.sendMultipleInstructions)(chatSdk.errors || tokenBondingSdk.errors || new Map(), chatSdk.provider, [
                    ...readPermissionInstructions,
                    ...postPermissionInstructions,
                    ...chatOut.instructions,
                ], [
                    ...readPermissionSigners,
                    ...postPermissionSigners,
                    ...chatOut.signers,
                ]);
                setState({ status: "success", subStatus: undefined });
            }
            catch (e) {
                setState({
                    status: undefined,
                    subStatus: undefined,
                    error: e,
                });
            }
        }
        else {
            setState({ status: undefined, subStatus: undefined });
        }
    }
});
exports.wizardSubmit = wizardSubmit;
//# sourceMappingURL=wizardSubmit.js.map