"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NewCommunities = void 0;
const react_1 = __importDefault(require("react"));
const useChatIdFromIdentifierCertificate_1 = require("../../../src/hooks/useChatIdFromIdentifierCertificate");
const useChats_1 = require("../../../src/hooks/useChats");
const react_2 = require("@chakra-ui/react");
const react_3 = require("@strata-foundation/react");
const router_1 = require("next/router");
const routes_1 = require("../../routes");
const ActiveUsers_1 = require("./ActiveUsers");
const FeaturedCommunities_1 = require("./FeaturedCommunities");
const Community = ({ imageUrl, name, identifierCertificateMint, dailyActiveUsers, }) => {
    const mintKey = (0, react_3.usePublicKey)(identifierCertificateMint);
    const { chatId: id } = (0, useChatIdFromIdentifierCertificate_1.useChatIdFromIdentifierCertificate)(mintKey);
    const router = (0, router_1.useRouter)();
    return (react_1.default.createElement(react_2.VStack, { position: "relative", p: "0", rounded: "2xl", borderColor: (0, react_2.useColorModeValue)("gray.100", "gray.700"), borderWidth: "1px" },
        react_1.default.createElement(react_2.Image, { roundedTop: "2xl", style: { height: "60%" }, objectFit: "cover", w: "full", alt: name, src: imageUrl }),
        react_1.default.createElement(react_2.VStack, { spacing: 6, w: "full", p: 4 },
            react_1.default.createElement(react_2.VStack, { align: "stretch", w: "full", spacing: 2 },
                react_1.default.createElement(react_2.Text, { mb: "-10px", lineHeight: "120%", fontWeight: "extrabold", noOfLines: 2, textAlign: "left", fontSize: "2xl" }, name),
                react_1.default.createElement(react_2.Text, { fontSize: "12px", color: (0, react_2.useColorModeValue)("gray.700", "gray.100") },
                    id,
                    ".chat")),
            react_1.default.createElement(react_2.HStack, { spacing: 2 }, typeof dailyActiveUsers !== "undefined" && (react_1.default.createElement(ActiveUsers_1.ActiveUsers, { num: dailyActiveUsers, fontSize: "12px" }))),
            react_1.default.createElement(react_2.Button, { w: "full", onClick: () => router.push((0, routes_1.route)(routes_1.routes.chat, {
                    id,
                }), undefined, {
                    shallow: true,
                }), colorScheme: "primary" }, "Join Now!"))));
};
const featuredKeys = new Set(FeaturedCommunities_1.FEATURED_COMMUNITIES.map((c) => c.publicKey));
const NewCommunities = () => {
    const { chats } = (0, useChats_1.useChats)();
    if (chats.length == 0)
        return null;
    return (react_1.default.createElement(react_2.Stack, { direction: "column", align: "start", spacing: 4, w: "full", pb: "100px", pt: 8 },
        react_1.default.createElement(react_2.Stack, { gap: 2 },
            react_1.default.createElement(react_2.Text, { fontSize: "sm", fontWeight: "semibold", color: "cyan.500" }, "BE A PART OF SOMETHING"),
            react_1.default.createElement(react_2.Text, { fontSize: "3xl", fontWeight: "bold" }, "New Communities"),
            react_1.default.createElement(react_2.Text, { w: "400px" }, "Join one of the already existing communities and begin chatting with your peers!")),
        react_1.default.createElement(react_2.SimpleGrid, { columns: { sm: 2, md: 3, lg: 4 }, spacing: 4 }, chats
            .filter((chat) => !featuredKeys.has(chat.publicKey))
            .map((chat) => (react_1.default.createElement(Community, Object.assign({ key: chat.publicKey }, chat)))))));
};
exports.NewCommunities = NewCommunities;
//# sourceMappingURL=NewCommunities.js.map